import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.spsp_listperiods_fixture_type import SpspListperiodsFixtureType
from ...models.spsp_listperiods_home_away import SpspListperiodsHomeAway
from ...models.spsp_listperiods_period_id import SpspListperiodsPeriodId
from ...models.spsp_listperiods_response_default import SpspListperiodsResponseDefault
from ...models.spsp_listperiods_win_loss import SpspListperiodsWinLoss
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    season_id: UUID,
    *,
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SpspListperiodsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SpspListperiodsHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    period_id: Union[Unset, SpspListperiodsPeriodId] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    section: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    win_loss: Union[Unset, SpspListperiodsWinLoss] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_entity_id: Union[Unset, str] = UNSET
    if not isinstance(entity_id, Unset):
        json_entity_id = str(entity_id)
    params["entityId"] = json_entity_id

    params["external"] = external

    params["fields"] = fields

    json_fixture_type: Union[Unset, str] = UNSET
    if not isinstance(fixture_type, Unset):
        json_fixture_type = fixture_type.value

    params["fixtureType"] = json_fixture_type

    json_from_time_local: Union[Unset, str] = UNSET
    if not isinstance(from_time_local, Unset):
        json_from_time_local = from_time_local.isoformat()
    params["fromTimeLocal"] = json_from_time_local

    json_from_time_utc: Union[Unset, str] = UNSET
    if not isinstance(from_time_utc, Unset):
        json_from_time_utc = from_time_utc.isoformat()
    params["fromTimeUTC"] = json_from_time_utc

    params["hideNull"] = hide_null

    json_home_away: Union[Unset, str] = UNSET
    if not isinstance(home_away, Unset):
        json_home_away = home_away.value

    params["homeAway"] = json_home_away

    params["include"] = include

    params["isPlayer"] = is_player

    params["isTeamOfficial"] = is_team_official

    params["limit"] = limit

    params["offset"] = offset

    json_period_id: Union[Unset, int] = UNSET
    if not isinstance(period_id, Unset):
        json_period_id = period_id.value

    params["periodId"] = json_period_id

    json_person_id: Union[Unset, str] = UNSET
    if not isinstance(person_id, Unset):
        json_person_id = str(person_id)
    params["personId"] = json_person_id

    params["poolCode"] = pool_code

    params["roundCode"] = round_code

    params["roundNumber"] = round_number

    params["section"] = section

    params["stageCode"] = stage_code

    params["starter"] = starter

    json_to_time_local: Union[Unset, str] = UNSET
    if not isinstance(to_time_local, Unset):
        json_to_time_local = to_time_local.isoformat()
    params["toTimeLocal"] = json_to_time_local

    json_to_time_utc: Union[Unset, str] = UNSET
    if not isinstance(to_time_utc, Unset):
        json_to_time_utc = to_time_utc.isoformat()
    params["toTimeUTC"] = json_to_time_utc

    json_win_loss: Union[Unset, str] = UNSET
    if not isinstance(win_loss, Unset):
        json_win_loss = win_loss.value

    params["winLoss"] = json_win_loss

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/statistics/for/person/in/seasons/{season_id}/periods",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> SpspListperiodsResponseDefault:
    response_default = SpspListperiodsResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[SpspListperiodsResponseDefault]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SpspListperiodsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SpspListperiodsHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    period_id: Union[Unset, SpspListperiodsPeriodId] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    section: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    win_loss: Union[Unset, SpspListperiodsWinLoss] = UNSET,
) -> Response[SpspListperiodsResponseDefault]:
    """Person season statistics by period

     Return a list of person statistics for a season broken down and filterable by period.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SpspListperiodsFixtureType]):  Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SpspListperiodsHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        period_id (Union[Unset, SpspListperiodsPeriodId]):
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        section (Union[Unset, str]):
        stage_code (Union[Unset, str]):  Example: ST1.
        starter (Union[Unset, bool]):
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        win_loss (Union[Unset, SpspListperiodsWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SpspListperiodsResponseDefault]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        home_away=home_away,
        include=include,
        is_player=is_player,
        is_team_official=is_team_official,
        limit=limit,
        offset=offset,
        period_id=period_id,
        person_id=person_id,
        pool_code=pool_code,
        round_code=round_code,
        round_number=round_number,
        section=section,
        stage_code=stage_code,
        starter=starter,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        win_loss=win_loss,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SpspListperiodsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SpspListperiodsHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    period_id: Union[Unset, SpspListperiodsPeriodId] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    section: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    win_loss: Union[Unset, SpspListperiodsWinLoss] = UNSET,
) -> Optional[SpspListperiodsResponseDefault]:
    """Person season statistics by period

     Return a list of person statistics for a season broken down and filterable by period.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SpspListperiodsFixtureType]):  Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SpspListperiodsHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        period_id (Union[Unset, SpspListperiodsPeriodId]):
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        section (Union[Unset, str]):
        stage_code (Union[Unset, str]):  Example: ST1.
        starter (Union[Unset, bool]):
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        win_loss (Union[Unset, SpspListperiodsWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SpspListperiodsResponseDefault
    """

    return sync_detailed(
        organization_id=organization_id,
        season_id=season_id,
        client=client,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        home_away=home_away,
        include=include,
        is_player=is_player,
        is_team_official=is_team_official,
        limit=limit,
        offset=offset,
        period_id=period_id,
        person_id=person_id,
        pool_code=pool_code,
        round_code=round_code,
        round_number=round_number,
        section=section,
        stage_code=stage_code,
        starter=starter,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        win_loss=win_loss,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SpspListperiodsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SpspListperiodsHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    period_id: Union[Unset, SpspListperiodsPeriodId] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    section: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    win_loss: Union[Unset, SpspListperiodsWinLoss] = UNSET,
) -> Response[SpspListperiodsResponseDefault]:
    """Person season statistics by period

     Return a list of person statistics for a season broken down and filterable by period.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SpspListperiodsFixtureType]):  Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SpspListperiodsHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        period_id (Union[Unset, SpspListperiodsPeriodId]):
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        section (Union[Unset, str]):
        stage_code (Union[Unset, str]):  Example: ST1.
        starter (Union[Unset, bool]):
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        win_loss (Union[Unset, SpspListperiodsWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SpspListperiodsResponseDefault]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        home_away=home_away,
        include=include,
        is_player=is_player,
        is_team_official=is_team_official,
        limit=limit,
        offset=offset,
        period_id=period_id,
        person_id=person_id,
        pool_code=pool_code,
        round_code=round_code,
        round_number=round_number,
        section=section,
        stage_code=stage_code,
        starter=starter,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        win_loss=win_loss,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, SpspListperiodsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    home_away: Union[Unset, SpspListperiodsHomeAway] = UNSET,
    include: Union[Unset, str] = UNSET,
    is_player: Union[Unset, bool] = UNSET,
    is_team_official: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    period_id: Union[Unset, SpspListperiodsPeriodId] = UNSET,
    person_id: Union[Unset, UUID] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    section: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    starter: Union[Unset, bool] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    win_loss: Union[Unset, SpspListperiodsWinLoss] = UNSET,
) -> Optional[SpspListperiodsResponseDefault]:
    """Person season statistics by period

     Return a list of person statistics for a season broken down and filterable by period.

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, SpspListperiodsFixtureType]):  Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        home_away (Union[Unset, SpspListperiodsHomeAway]):
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        is_player (Union[Unset, bool]):
        is_team_official (Union[Unset, bool]):
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        period_id (Union[Unset, SpspListperiodsPeriodId]):
        person_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        section (Union[Unset, str]):
        stage_code (Union[Unset, str]):  Example: ST1.
        starter (Union[Unset, bool]):
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        win_loss (Union[Unset, SpspListperiodsWinLoss]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SpspListperiodsResponseDefault
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            season_id=season_id,
            client=client,
            entity_id=entity_id,
            external=external,
            fields=fields,
            fixture_type=fixture_type,
            from_time_local=from_time_local,
            from_time_utc=from_time_utc,
            hide_null=hide_null,
            home_away=home_away,
            include=include,
            is_player=is_player,
            is_team_official=is_team_official,
            limit=limit,
            offset=offset,
            period_id=period_id,
            person_id=person_id,
            pool_code=pool_code,
            round_code=round_code,
            round_number=round_number,
            section=section,
            stage_code=stage_code,
            starter=starter,
            to_time_local=to_time_local,
            to_time_utc=to_time_utc,
            win_loss=win_loss,
        )
    ).parsed



from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.pss_list_age_group import PssListAgeGroup
from ...models.pss_list_fixture_type import PssListFixtureType
from ...models.pss_list_representation import PssListRepresentation
from ...models.pss_list_response_default import PssListResponseDefault
from ...models.pss_list_season_person_statistics_response import PssListSeasonPersonStatisticsResponse
from ...models.pss_list_season_type import PssListSeasonType
from ...models.pss_list_standard import PssListStandard
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    person_id: UUID,
    *,
    age_group: Union[Unset, PssListAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, PssListFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, PssListRepresentation] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_type: Union[Unset, PssListSeasonType] = UNSET,
    standard: Union[Unset, PssListStandard] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_age_group: Union[Unset, str] = UNSET
    if not isinstance(age_group, Unset):
        json_age_group = age_group.value

    params["ageGroup"] = json_age_group

    json_competition_id: Union[Unset, str] = UNSET
    if not isinstance(competition_id, Unset):
        json_competition_id = str(competition_id)
    params["competitionId"] = json_competition_id

    params["external"] = external

    params["fields"] = fields

    json_fixture_type: Union[Unset, str] = UNSET
    if not isinstance(fixture_type, Unset):
        json_fixture_type = fixture_type.value

    params["fixtureType"] = json_fixture_type

    params["hideNull"] = hide_null

    params["include"] = include

    params["limit"] = limit

    params["offset"] = offset

    json_representation: Union[Unset, str] = UNSET
    if not isinstance(representation, Unset):
        json_representation = representation.value

    params["representation"] = json_representation

    json_season_id: Union[Unset, str] = UNSET
    if not isinstance(season_id, Unset):
        json_season_id = str(season_id)
    params["seasonId"] = json_season_id

    json_season_type: Union[Unset, str] = UNSET
    if not isinstance(season_type, Unset):
        json_season_type = season_type.value

    params["seasonType"] = json_season_type

    json_standard: Union[Unset, str] = UNSET
    if not isinstance(standard, Unset):
        json_standard = standard.value

    params["standard"] = json_standard

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/statistics/for/person/{person_id}/in/seasons",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]:
    if response.status_code == 200:
        response_200 = PssListSeasonPersonStatisticsResponse.from_dict(response.json())

        return response_200

    response_default = PssListResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    person_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    age_group: Union[Unset, PssListAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, PssListFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, PssListRepresentation] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_type: Union[Unset, PssListSeasonType] = UNSET,
    standard: Union[Unset, PssListStandard] = UNSET,
) -> Response[Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]]:
    """Person season statistics

     Return a list of person statistics for all seasons

    Args:
        organization_id (str):  Example: b1a23.
        person_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        age_group (Union[Unset, PssListAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, PssListFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, PssListRepresentation]):  Example: CLUB.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_type (Union[Unset, PssListSeasonType]):  Example: SEASON.
        standard (Union[Unset, PssListStandard]):  Example: ELITE.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        person_id=person_id,
        age_group=age_group,
        competition_id=competition_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        representation=representation,
        season_id=season_id,
        season_type=season_type,
        standard=standard,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    person_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    age_group: Union[Unset, PssListAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, PssListFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, PssListRepresentation] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_type: Union[Unset, PssListSeasonType] = UNSET,
    standard: Union[Unset, PssListStandard] = UNSET,
) -> Optional[Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]]:
    """Person season statistics

     Return a list of person statistics for all seasons

    Args:
        organization_id (str):  Example: b1a23.
        person_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        age_group (Union[Unset, PssListAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, PssListFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, PssListRepresentation]):  Example: CLUB.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_type (Union[Unset, PssListSeasonType]):  Example: SEASON.
        standard (Union[Unset, PssListStandard]):  Example: ELITE.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]
    """

    return sync_detailed(
        organization_id=organization_id,
        person_id=person_id,
        client=client,
        age_group=age_group,
        competition_id=competition_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        representation=representation,
        season_id=season_id,
        season_type=season_type,
        standard=standard,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    person_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    age_group: Union[Unset, PssListAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, PssListFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, PssListRepresentation] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_type: Union[Unset, PssListSeasonType] = UNSET,
    standard: Union[Unset, PssListStandard] = UNSET,
) -> Response[Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]]:
    """Person season statistics

     Return a list of person statistics for all seasons

    Args:
        organization_id (str):  Example: b1a23.
        person_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        age_group (Union[Unset, PssListAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, PssListFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, PssListRepresentation]):  Example: CLUB.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_type (Union[Unset, PssListSeasonType]):  Example: SEASON.
        standard (Union[Unset, PssListStandard]):  Example: ELITE.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        person_id=person_id,
        age_group=age_group,
        competition_id=competition_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        representation=representation,
        season_id=season_id,
        season_type=season_type,
        standard=standard,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    person_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    age_group: Union[Unset, PssListAgeGroup] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, PssListFixtureType] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    representation: Union[Unset, PssListRepresentation] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_type: Union[Unset, PssListSeasonType] = UNSET,
    standard: Union[Unset, PssListStandard] = UNSET,
) -> Optional[Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]]:
    """Person season statistics

     Return a list of person statistics for all seasons

    Args:
        organization_id (str):  Example: b1a23.
        person_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        age_group (Union[Unset, PssListAgeGroup]):  Example: SENIOR.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, PssListFixtureType]):  Example: REGULAR.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        representation (Union[Unset, PssListRepresentation]):  Example: CLUB.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_type (Union[Unset, PssListSeasonType]):  Example: SEASON.
        standard (Union[Unset, PssListStandard]):  Example: ELITE.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[PssListResponseDefault, PssListSeasonPersonStatisticsResponse]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            person_id=person_id,
            client=client,
            age_group=age_group,
            competition_id=competition_id,
            external=external,
            fields=fields,
            fixture_type=fixture_type,
            hide_null=hide_null,
            include=include,
            limit=limit,
            offset=offset,
            representation=representation,
            season_id=season_id,
            season_type=season_type,
            standard=standard,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.match_roster_model_position_type_1 import MatchRosterModelPositionType1
from ..models.match_roster_model_position_type_2_type_1 import MatchRosterModelPositionType2Type1
from ..models.match_roster_model_position_type_3_type_1 import MatchRosterModelPositionType3Type1
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.match_roster_model_entity import MatchRosterModelEntity
    from ..models.match_roster_model_fixture import MatchRosterModelFixture
    from ..models.match_roster_model_organization import MatchRosterModelOrganization
    from ..models.match_roster_model_person import MatchRosterModelPerson


T = TypeVar("T", bound="MatchRosterModel")


@_attrs_define
class MatchRosterModel:
    """
    Attributes:
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, MatchRosterModelFixture]): The match
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, MatchRosterModelOrganization]): The organization that this match roster belongs to
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, MatchRosterModelEntity]): The team information
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, MatchRosterModelPerson]): The person information
        bib (Union[None, Unset, str]): The number displayed on the jersey Example: 34.
        position (Union[MatchRosterModelPositionType1, MatchRosterModelPositionType2Type1,
            MatchRosterModelPositionType3Type1, None, Unset]): Playing position
            >- None None
            >- `CB` Center Backcourt
            >- `D` Defensive Specialist
            >- `G` Goalkeeper
            >- `LB` Left Backcourt
            >- `LW` Left Wingman
            >- `P` Pivot
            >- `RB` Right Backcourt
            >- `RW` Right Wingman
             Example: G.
        starter (Union[Unset, bool]): Did person start the match on the court Example: True.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "MatchRosterModelFixture"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "MatchRosterModelOrganization"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "MatchRosterModelEntity"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "MatchRosterModelPerson"] = UNSET
    bib: Union[None, Unset, str] = UNSET
    position: Union[
        MatchRosterModelPositionType1,
        MatchRosterModelPositionType2Type1,
        MatchRosterModelPositionType3Type1,
        None,
        Unset,
    ] = UNSET
    starter: Union[Unset, bool] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        bib: Union[None, Unset, str]
        if isinstance(self.bib, Unset):
            bib = UNSET
        else:
            bib = self.bib

        position: Union[None, Unset, str]
        if isinstance(self.position, Unset):
            position = UNSET
        elif isinstance(self.position, MatchRosterModelPositionType1):
            position = self.position.value
        elif isinstance(self.position, MatchRosterModelPositionType2Type1):
            position = self.position.value
        elif isinstance(self.position, MatchRosterModelPositionType3Type1):
            position = self.position.value
        else:
            position = self.position

        starter = self.starter

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if bib is not UNSET:
            field_dict["bib"] = bib
        if position is not UNSET:
            field_dict["position"] = position
        if starter is not UNSET:
            field_dict["starter"] = starter
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.match_roster_model_entity import MatchRosterModelEntity
        from ..models.match_roster_model_fixture import MatchRosterModelFixture
        from ..models.match_roster_model_organization import MatchRosterModelOrganization
        from ..models.match_roster_model_person import MatchRosterModelPerson

        d = dict(src_dict)
        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, MatchRosterModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = MatchRosterModelFixture.from_dict(_fixture)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, MatchRosterModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = MatchRosterModelOrganization.from_dict(_organization)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, MatchRosterModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = MatchRosterModelEntity.from_dict(_entity)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, MatchRosterModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = MatchRosterModelPerson.from_dict(_person)

        def _parse_bib(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        bib = _parse_bib(d.pop("bib", UNSET))

        def _parse_position(
            data: object,
        ) -> Union[
            MatchRosterModelPositionType1,
            MatchRosterModelPositionType2Type1,
            MatchRosterModelPositionType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_1 = MatchRosterModelPositionType1(data)

                return position_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_2_type_1 = MatchRosterModelPositionType2Type1(data)

                return position_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                position_type_3_type_1 = MatchRosterModelPositionType3Type1(data)

                return position_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    MatchRosterModelPositionType1,
                    MatchRosterModelPositionType2Type1,
                    MatchRosterModelPositionType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        position = _parse_position(d.pop("position", UNSET))

        starter = d.pop("starter", UNSET)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        match_roster_model = cls(
            fixture_id=fixture_id,
            fixture=fixture,
            organization_id=organization_id,
            organization=organization,
            entity_id=entity_id,
            entity=entity,
            person_id=person_id,
            person=person,
            bib=bib,
            position=position,
            starter=starter,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return match_roster_model



from enum import Enum


class HeadToHeadListFixturesStatus(str, Enum):
    ABANDONED = "ABANDONED"
    ABOUT_TO_START = "ABOUT_TO_START"
    BYE = "BYE"
    CANCELLED = "CANCELLED"
    CONFIRMED = "CONFIRMED"
    DRAFT = "DRAFT"
    FINISHED = "FINISHED"
    IF_NEEDED = "IF_NEEDED"
    IN_PROGRESS = "IN_PROGRESS"
    ON_PITCH = "ON_PITCH"
    PENDING = "PENDING"
    POSTPONED = "POSTPONED"
    SCHEDULED = "SCHEDULED"
    WARM_UP = "WARM_UP"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.fixture_pbp_external_model_period_id import FixturePbpExternalModelPeriodId
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.fixture_pbp_external_model_event_details import FixturePbpExternalModelEventDetails
    from ..models.fixture_pbp_external_model_fixture import FixturePbpExternalModelFixture
    from ..models.fixture_pbp_external_model_organization import FixturePbpExternalModelOrganization


T = TypeVar("T", bound="FixturePbpExternalModel")


@_attrs_define
class FixturePbpExternalModel:
    """
    Attributes:
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, FixturePbpExternalModelOrganization]): The organization that this
            fixture_pbp_external belongs to
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, FixturePbpExternalModelFixture]): The match
        period_id (Union[Unset, FixturePbpExternalModelPeriodId]): The identifier for the period
            >- `1` Period 1
            >- `2` Period 2
            >- `10` Extra time 1 period 1
            >- `11` Extra time 1 period 2
            >- `12` Extra time 2 period 1
            >- `13` Extra time 2 period 2
            >- `14` Shoot Out
        section (Union[Unset, str]): The section of the period (sub-period)
        events (Union['FixturePbpExternalModelEventDetails', None, Unset]): Event details
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "FixturePbpExternalModelOrganization"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "FixturePbpExternalModelFixture"] = UNSET
    period_id: Union[Unset, FixturePbpExternalModelPeriodId] = UNSET
    section: Union[Unset, str] = UNSET
    events: Union["FixturePbpExternalModelEventDetails", None, Unset] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.fixture_pbp_external_model_event_details import FixturePbpExternalModelEventDetails

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        period_id: Union[Unset, int] = UNSET
        if not isinstance(self.period_id, Unset):
            period_id = self.period_id.value

        section = self.section

        events: Union[None, Unset, dict[str, Any]]
        if isinstance(self.events, Unset):
            events = UNSET
        elif isinstance(self.events, FixturePbpExternalModelEventDetails):
            events = self.events.to_dict()
        else:
            events = self.events

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if period_id is not UNSET:
            field_dict["periodId"] = period_id
        if section is not UNSET:
            field_dict["section"] = section
        if events is not UNSET:
            field_dict["events"] = events
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.fixture_pbp_external_model_event_details import FixturePbpExternalModelEventDetails
        from ..models.fixture_pbp_external_model_fixture import FixturePbpExternalModelFixture
        from ..models.fixture_pbp_external_model_organization import FixturePbpExternalModelOrganization

        d = dict(src_dict)
        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, FixturePbpExternalModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = FixturePbpExternalModelOrganization.from_dict(_organization)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, FixturePbpExternalModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = FixturePbpExternalModelFixture.from_dict(_fixture)

        _period_id = d.pop("periodId", UNSET)
        period_id: Union[Unset, FixturePbpExternalModelPeriodId]
        if isinstance(_period_id, Unset):
            period_id = UNSET
        else:
            period_id = FixturePbpExternalModelPeriodId(_period_id)

        section = d.pop("section", UNSET)

        def _parse_events(data: object) -> Union["FixturePbpExternalModelEventDetails", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                events_type_0 = FixturePbpExternalModelEventDetails.from_dict(data)

                return events_type_0
            except:  # noqa: E722
                pass
            return cast(Union["FixturePbpExternalModelEventDetails", None, Unset], data)

        events = _parse_events(d.pop("events", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        fixture_pbp_external_model = cls(
            organization_id=organization_id,
            organization=organization,
            fixture_id=fixture_id,
            fixture=fixture,
            period_id=period_id,
            section=section,
            events=events,
            updated=updated,
            added=added,
        )

        return fixture_pbp_external_model



from enum import Enum


class SeasonRosterModelPositionType3Type1(str, Enum):
    CB = "CB"
    D = "D"
    G = "G"
    LB = "LB"
    LW = "LW"
    P = "P"
    RB = "RB"
    RW = "RW"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.match_model_broadcasts_broadcast_type import MatchModelBroadcastsBroadcastType
from ..types import UNSET, Unset

T = TypeVar("T", bound="MatchModelBroadcasts")


@_attrs_define
class MatchModelBroadcasts:
    """
    Attributes:
        broadcast_type (Union[Unset, MatchModelBroadcastsBroadcastType]): Broadcast Type Example: TV.
        broadcaster (Union[Unset, str]): Broadcaster Name Local Example: XYZ Network.
        broadcaster_url (Union[Unset, str]): Broadcaster Home URL Example: www.XYZNetwork.com.
        broadcast_url (Union[Unset, str]): Fixture Broadcast URL Example: www.XYZNetwork.com/fixture/123.
        broadcast_timezone (Union[Unset, str]): Timezone of the broadcast Example: Australia/Sydney.
        locale (Union[Unset, str]): Locale of the broadcast Example: en-EN.
        start_time_local (Union[Unset, Any]): Start Time of the broadcast Example: 2023-01-01.
    """

    broadcast_type: Union[Unset, MatchModelBroadcastsBroadcastType] = UNSET
    broadcaster: Union[Unset, str] = UNSET
    broadcaster_url: Union[Unset, str] = UNSET
    broadcast_url: Union[Unset, str] = UNSET
    broadcast_timezone: Union[Unset, str] = UNSET
    locale: Union[Unset, str] = UNSET
    start_time_local: Union[Unset, Any] = UNSET

    def to_dict(self) -> dict[str, Any]:
        broadcast_type: Union[Unset, str] = UNSET
        if not isinstance(self.broadcast_type, Unset):
            broadcast_type = self.broadcast_type.value

        broadcaster = self.broadcaster

        broadcaster_url = self.broadcaster_url

        broadcast_url = self.broadcast_url

        broadcast_timezone = self.broadcast_timezone

        locale = self.locale

        start_time_local = self.start_time_local

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if broadcast_type is not UNSET:
            field_dict["broadcastType"] = broadcast_type
        if broadcaster is not UNSET:
            field_dict["broadcaster"] = broadcaster
        if broadcaster_url is not UNSET:
            field_dict["broadcasterURL"] = broadcaster_url
        if broadcast_url is not UNSET:
            field_dict["broadcastURL"] = broadcast_url
        if broadcast_timezone is not UNSET:
            field_dict["broadcastTimezone"] = broadcast_timezone
        if locale is not UNSET:
            field_dict["locale"] = locale
        if start_time_local is not UNSET:
            field_dict["startTimeLocal"] = start_time_local

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _broadcast_type = d.pop("broadcastType", UNSET)
        broadcast_type: Union[Unset, MatchModelBroadcastsBroadcastType]
        if isinstance(_broadcast_type, Unset):
            broadcast_type = UNSET
        else:
            broadcast_type = MatchModelBroadcastsBroadcastType(_broadcast_type)

        broadcaster = d.pop("broadcaster", UNSET)

        broadcaster_url = d.pop("broadcasterURL", UNSET)

        broadcast_url = d.pop("broadcastURL", UNSET)

        broadcast_timezone = d.pop("broadcastTimezone", UNSET)

        locale = d.pop("locale", UNSET)

        start_time_local = d.pop("startTimeLocal", UNSET)

        match_model_broadcasts = cls(
            broadcast_type=broadcast_type,
            broadcaster=broadcaster,
            broadcaster_url=broadcaster_url,
            broadcast_url=broadcast_url,
            broadcast_timezone=broadcast_timezone,
            locale=locale,
            start_time_local=start_time_local,
        )

        return match_model_broadcasts



from enum import Enum


class IncludedDataResourcesAdditionalProperty(str, Enum):
    LEAGUE = "league"
    ORGANISATION = "organisation"
    PERSONS = "persons"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class SeasonModelRepresentation(str, Enum):
    CLUB = "CLUB"
    COUNTRY = "COUNTRY"
    PERSON = "PERSON"
    REGION = "REGION"
    STATE = "STATE"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class MatchModelMaximumPeriodTypeUsedType2Type1(str, Enum):
    EXTRA_TIME = "EXTRA_TIME"
    OVERTIME = "OVERTIME"
    REGULAR = "REGULAR"
    SHOOTOUT = "SHOOTOUT"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.match_team_statistics_model_entity import MatchTeamStatisticsModelEntity
    from ..models.match_team_statistics_model_fixture import MatchTeamStatisticsModelFixture
    from ..models.match_team_statistics_model_organization import MatchTeamStatisticsModelOrganization
    from ..models.match_team_statistics_model_statistics import MatchTeamStatisticsModelStatistics


T = TypeVar("T", bound="MatchTeamStatisticsModel")


@_attrs_define
class MatchTeamStatisticsModel:
    """
    Attributes:
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, MatchTeamStatisticsModelEntity]): The team information
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, MatchTeamStatisticsModelFixture]): The match
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, MatchTeamStatisticsModelOrganization]): The organization that this match team
            statistics belongs to
        statistics (Union[Unset, MatchTeamStatisticsModelStatistics]):
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "MatchTeamStatisticsModelEntity"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "MatchTeamStatisticsModelFixture"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "MatchTeamStatisticsModelOrganization"] = UNSET
    statistics: Union[Unset, "MatchTeamStatisticsModelStatistics"] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if statistics is not UNSET:
            field_dict["statistics"] = statistics
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.match_team_statistics_model_entity import MatchTeamStatisticsModelEntity
        from ..models.match_team_statistics_model_fixture import MatchTeamStatisticsModelFixture
        from ..models.match_team_statistics_model_organization import MatchTeamStatisticsModelOrganization
        from ..models.match_team_statistics_model_statistics import MatchTeamStatisticsModelStatistics

        d = dict(src_dict)
        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, MatchTeamStatisticsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = MatchTeamStatisticsModelEntity.from_dict(_entity)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, MatchTeamStatisticsModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = MatchTeamStatisticsModelFixture.from_dict(_fixture)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, MatchTeamStatisticsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = MatchTeamStatisticsModelOrganization.from_dict(_organization)

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, MatchTeamStatisticsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = MatchTeamStatisticsModelStatistics.from_dict(_statistics)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        match_team_statistics_model = cls(
            entity_id=entity_id,
            entity=entity,
            fixture_id=fixture_id,
            fixture=fixture,
            organization_id=organization_id,
            organization=organization,
            statistics=statistics,
            updated=updated,
            added=added,
        )

        return match_team_statistics_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_stage_model_organization import SeasonStageModelOrganization
    from ..models.season_stage_model_season import SeasonStageModelSeason


T = TypeVar("T", bound="SeasonStageModel")


@_attrs_define
class SeasonStageModel:
    """
    Attributes:
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonStageModelSeason]): The season linked to this record
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonStageModelOrganization]): The organization that this season stage belongs to
        stage_code (Union[Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        name_local (Union[None, Unset, str]): The name of the season stage in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: Test name local.
        abbreviation_local (Union[None, Unset, str]): An abbreviation/short name in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: NFA.
        name_latin (Union[None, Unset, str]): The name of the season stage in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: Test name latin .
        abbreviation_latin (Union[None, Unset, str]): An abbreviation/short name in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: NFA.
        stage_order (Union[None, Unset, int]): User defined sort order of the stage Example: 1.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonStageModelSeason"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonStageModelOrganization"] = UNSET
    stage_code: Union[Unset, str] = UNSET
    name_local: Union[None, Unset, str] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    abbreviation_latin: Union[None, Unset, str] = UNSET
    stage_order: Union[None, Unset, int] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        stage_code = self.stage_code

        name_local: Union[None, Unset, str]
        if isinstance(self.name_local, Unset):
            name_local = UNSET
        else:
            name_local = self.name_local

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        stage_order: Union[None, Unset, int]
        if isinstance(self.stage_order, Unset):
            stage_order = UNSET
        else:
            stage_order = self.stage_order

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin
        if stage_order is not UNSET:
            field_dict["stageOrder"] = stage_order
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_stage_model_organization import SeasonStageModelOrganization
        from ..models.season_stage_model_season import SeasonStageModelSeason

        d = dict(src_dict)
        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonStageModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonStageModelSeason.from_dict(_season)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonStageModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonStageModelOrganization.from_dict(_organization)

        stage_code = d.pop("stageCode", UNSET)

        def _parse_name_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_local = _parse_name_local(d.pop("nameLocal", UNSET))

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        def _parse_stage_order(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        stage_order = _parse_stage_order(d.pop("stageOrder", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        season_stage_model = cls(
            season_id=season_id,
            season=season,
            organization_id=organization_id,
            organization=organization,
            stage_code=stage_code,
            name_local=name_local,
            abbreviation_local=abbreviation_local,
            name_latin=name_latin,
            abbreviation_latin=abbreviation_latin,
            stage_order=stage_order,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return season_stage_model



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="VenueModelVenueHistoricalName")


@_attrs_define
class VenueModelVenueHistoricalName:
    """
    Attributes:
        date_start (Union[None, Unset, datetime.date]): Start date
        date_end (Union[None, Unset, datetime.date]): End date
        name_local (Union[None, Unset, str]): Full name in local language
        name_latin (Union[None, Unset, str]): Full name in latin characters
        alternate_name_local (Union[None, Unset, str]): Alternate name in local lanuage
        alternate_name_latin (Union[None, Unset, str]): Alternate name in latin characters
        abbreviation_local (Union[None, Unset, str]): Abbreviation in local lanuage
        abbreviation_latin (Union[None, Unset, str]): Abbreviation in latin characters
    """

    date_start: Union[None, Unset, datetime.date] = UNSET
    date_end: Union[None, Unset, datetime.date] = UNSET
    name_local: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    alternate_name_local: Union[None, Unset, str] = UNSET
    alternate_name_latin: Union[None, Unset, str] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    abbreviation_latin: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        date_start: Union[None, Unset, str]
        if isinstance(self.date_start, Unset):
            date_start = UNSET
        elif isinstance(self.date_start, datetime.date):
            date_start = self.date_start.isoformat()
        else:
            date_start = self.date_start

        date_end: Union[None, Unset, str]
        if isinstance(self.date_end, Unset):
            date_end = UNSET
        elif isinstance(self.date_end, datetime.date):
            date_end = self.date_end.isoformat()
        else:
            date_end = self.date_end

        name_local: Union[None, Unset, str]
        if isinstance(self.name_local, Unset):
            name_local = UNSET
        else:
            name_local = self.name_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        alternate_name_local: Union[None, Unset, str]
        if isinstance(self.alternate_name_local, Unset):
            alternate_name_local = UNSET
        else:
            alternate_name_local = self.alternate_name_local

        alternate_name_latin: Union[None, Unset, str]
        if isinstance(self.alternate_name_latin, Unset):
            alternate_name_latin = UNSET
        else:
            alternate_name_latin = self.alternate_name_latin

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if date_start is not UNSET:
            field_dict["dateStart"] = date_start
        if date_end is not UNSET:
            field_dict["dateEnd"] = date_end
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if alternate_name_local is not UNSET:
            field_dict["alternateNameLocal"] = alternate_name_local
        if alternate_name_latin is not UNSET:
            field_dict["alternateNameLatin"] = alternate_name_latin
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_date_start(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_start_type_0 = isoparse(data).date()

                return date_start_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_start = _parse_date_start(d.pop("dateStart", UNSET))

        def _parse_date_end(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_end_type_0 = isoparse(data).date()

                return date_end_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_end = _parse_date_end(d.pop("dateEnd", UNSET))

        def _parse_name_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_local = _parse_name_local(d.pop("nameLocal", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_alternate_name_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        alternate_name_local = _parse_alternate_name_local(d.pop("alternateNameLocal", UNSET))

        def _parse_alternate_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        alternate_name_latin = _parse_alternate_name_latin(d.pop("alternateNameLatin", UNSET))

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        venue_model_venue_historical_name = cls(
            date_start=date_start,
            date_end=date_end,
            name_local=name_local,
            name_latin=name_latin,
            alternate_name_local=alternate_name_local,
            alternate_name_latin=alternate_name_latin,
            abbreviation_local=abbreviation_local,
            abbreviation_latin=abbreviation_latin,
        )

        return venue_model_venue_historical_name



from enum import Enum


class ImagesModelSecondaryTypeType3Type1(str, Enum):
    COMPETITION = "COMPETITION"
    CONFERENCE = "CONFERENCE"
    DIVISION = "DIVISION"
    ENTITY = "ENTITY"
    ENTITYGROUP = "ENTITYGROUP"
    LEAGUE = "LEAGUE"
    SEASON = "SEASON"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class SesListperiodsFixtureType(str, Enum):
    ALL_STAR = "ALL_STAR"
    DEMONSTRATION = "DEMONSTRATION"
    FINAL = "FINAL"
    FRIENDLY = "FRIENDLY"
    PLAYOFF = "PLAYOFF"
    PRESEASON = "PRESEASON"
    REGULAR = "REGULAR"

    def __str__(self) -> str:
        return str(self.value)



"""Handball API wrapper for Sportradar DataCore API.
Handles authentication, token management, and API requests.
Provides methods to access handball-related endpoints.

Author: Michael Adams, 2025
"""

import json
import logging
import uuid
from collections.abc import Sequence
from typing import Any, cast
from uuid import UUID

from datacore_client.api.competitions import competition_list
from datacore_client.api.match_persons import fixture_persons_list
from datacore_client.api.match_play_by_play import fixture_pbp_export
from datacore_client.api.matches import fixture_detail, fixture_list
from datacore_client.api.persons import person_list
from datacore_client.api.season_persons import season_persons_list
from datacore_client.api.season_teams import season_entities_list
from datacore_client.api.seasons import season_list
from datacore_client.api.teams import entity_detail

# from datacore_client.api.teams import entity_list
from datacore_client.models import (
    CompetitionListCompetitionsResponse,
    CompetitionModel,
    EntityDetailEntitiesResponse,
    FixtureDetailFixturesResponse,
    FixtureListFixturesResponse,
    FixturePbpExportSuccessResponse,
    FixturePersonsListFixturePersonsResponse,
    MatchModel,
    MatchPersonsModel,
    PersonListPersonsResponse,
    PersonModel,
    SeasonEntitiesListSeasonEntitiesListResponse,
    SeasonEntitiesModel,
    SeasonListSeasonsResponse,
    SeasonModel,
    SeasonPersonsListSeasonPersonsListResponse,
    SeasonPersonsModel,
    TeamModel,
)
from datacore_client.types import Unset

from sportradar_datacore_api.api import DataCoreAPI
from sportradar_datacore_api.errors import (
    NotFoundError,
    UnexpectedResponseError,
    ValidationError,
)

logger = logging.getLogger(__name__)
HTTP_OK = 200


class HandballAPI(DataCoreAPI):
    """
    Unified API wrapper for handball-related endpoints.
    Provides access to organizations, leagues, competitions,
    entities, persons, fixtures, etc.
    """

    # --- Public helpers requested -----------------------------------------

    def _require_org_id(self) -> str:
        if not self.org_id:
            raise ValidationError("org_id must be provided.")
        return self.org_id

    @staticmethod
    def _ensure_ok(response: Any, context: str) -> None:
        if response.status_code != HTTP_OK:
            raise UnexpectedResponseError(
                f"{context}: HTTP {response.status_code}: {response.content!r}"
            )

    @classmethod
    def _to_plain(cls, value: Any) -> Any:
        if isinstance(value, list):
            return [cls._to_plain(item) for item in value]
        if isinstance(value, dict):
            return {key: cls._to_plain(item) for key, item in value.items()}
        if hasattr(value, "model_dump"):
            return value.model_dump()
        if hasattr(value, "to_dict"):
            return value.to_dict()
        return value

    @classmethod
    def _json_data_from_response(cls, response: Any, context: str) -> Any:
        try:
            payload = json.loads(response.content)
        except json.JSONDecodeError as exc:
            raise UnexpectedResponseError(f"{context}: invalid JSON response") from exc
        if not isinstance(payload, dict):
            raise UnexpectedResponseError(f"{context}: unexpected JSON shape")
        return cls._to_plain(payload.get("data"))

    @staticmethod
    def _log_request(context: str, **details: Any) -> None:
        request_id = uuid.uuid4().hex
        logger.debug("%s request_id=%s details=%s", context, request_id, details)

    def get_competition_id_by_name(
        self,
        competition_name: str,
        *,
        limit: int = 50,
        offset: int | None = None,
    ) -> str:
        """
        Resolve a competition UUID by human-friendly name.
        Tries exact (case-insensitive) match on common name fields, then 'contains'.
        """
        # Efficiently fetch competitions with a higher limit to reduce API calls

        self._require_value("competition_name", competition_name)

        self._log_request(
            "competition_list",
            competition_name=competition_name,
            limit=limit,
            offset=offset,
        )

        organization_id = self._require_org_id()
        offset_value = self._as_offset(offset)

        resp = competition_list.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            name_local_contains=competition_name,  # Filter for Bundesliga competitions
            limit=limit,  # Increase limit for efficiency if expecting many results
            hide_null=True,  # Avoid null UUID fields that break model parsing
            offset=offset_value,
        )

        self._ensure_ok(resp, "competition_list")

        parsed = self._unwrap_response(
            resp.parsed,
            CompetitionListCompetitionsResponse,
            "competition_list",
        )
        data = parsed.data
        competitions: list[CompetitionModel] = (
            [] if isinstance(data, Unset) else list(data)
        )
        for c in competitions:
            if isinstance(c.name_local, str) and (
                c.name_local.casefold() == competition_name.casefold()
            ):
                return self._uuid_to_str(c.competition_id, "competition_id")
        raise NotFoundError(f"No competition found matching '{competition_name}'.")

    def get_season_id_by_year(
        self,
        competition_id: str | UUID,
        season_year: int,
        *,
        limit: int = 200,
        offset: int | None = None,
    ) -> str:
        """
        Resolve a season UUID by name under a given competition.
        Tries exact (case-insensitive) match on common name fields, then 'contains'.
        """
        self._require_value("competition_id", str(competition_id))
        competition_uuid = self._as_uuid(competition_id, "competition_id")

        self._log_request(
            "season_list",
            competition_id=str(competition_uuid),
            season_year=season_year,
            limit=limit,
            offset=offset,
        )

        organization_id = self._require_org_id()
        offset_value = self._as_offset(offset)

        response = season_list.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            competition_id=competition_uuid,
            limit=limit,
            offset=offset_value,
        )

        self._ensure_ok(response, "season_list")
        logger.info("Seasons fetched successfully.")
        logger.debug("Status Code: %s", response.status_code)
        parsed = self._unwrap_response(
            response.parsed, SeasonListSeasonsResponse, "season_list"
        )
        data = parsed.data
        seasons: list[SeasonModel] = [] if isinstance(data, Unset) else list(data)

        for c in seasons:
            logger.debug("Checking season: %s (%s)", c.name_local, c.season_id)

            if c.year == season_year:
                return self._uuid_to_str(c.season_id, "season_id")

        raise NotFoundError(
            f"No season found for competition '{competition_uuid}' in {season_year}."
        )

    def get_teams_by_season_id(
        self,
        season_id: str | UUID,
        *,
        limit: int = 100,
        offset: int | None = None,
    ) -> list[SeasonEntitiesModel]:
        """
        Return all teams for the given season.
        """
        self._require_value("season_id", str(season_id))
        season_uuid = self._as_uuid(season_id, "season_id")

        self._log_request(
            "season_entities_list",
            season_id=str(season_uuid),
            limit=limit,
            offset=offset,
        )
        organization_id = self._require_org_id()
        offset_value = self._as_offset(offset)
        resp = season_entities_list.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            season_id=season_uuid,
            include="entities,organizations",
            limit=limit,
            offset=offset_value,
            # fields=
        )

        self._ensure_ok(resp, "season_entities_list")

        parsed = self._unwrap_response(
            resp.parsed,
            SeasonEntitiesListSeasonEntitiesListResponse,
            "season_entities_list",
        )
        data = parsed.data
        if isinstance(data, Unset):
            return []
        return list(data)

    def get_players_by_season_id(
        self,
        season_id: str | UUID,
        *,
        limit: int = 200,
        offset: int | None = None,
    ) -> list[SeasonPersonsModel]:
        """
        Return all players for the given season.
        """
        self._require_value("season_id", str(season_id))
        season_uuid = self._as_uuid(season_id, "season_id")

        self._log_request(
            "season_persons_list",
            season_id=str(season_uuid),
            limit=limit,
            offset=offset,
        )
        organization_id = self._require_org_id()
        offset_value = self._as_offset(offset)
        resp = season_persons_list.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            season_id=season_uuid,
            include="entities,organizations",
            limit=limit,
            offset=offset_value,
        )

        self._ensure_ok(resp, "season_persons_list")

        parsed = self._unwrap_response(
            resp.parsed,
            SeasonPersonsListSeasonPersonsListResponse,
            "season_persons_list",
        )
        data = parsed.data
        if isinstance(data, Unset):
            return []
        return list(data)

    def list_players_by_match(
        self,
        match_id: str | UUID,
        *,
        limit: int = 200,
        offset: int | None = None,
    ) -> list[MatchPersonsModel]:
        """
        Return all players for the given match.
        """
        self._require_value("match_id", str(match_id))
        fixture_uuid = self._as_uuid(match_id, "match_id")

        self._log_request(
            "fixture_persons_list",
            match_id=str(fixture_uuid),
            limit=limit,
            offset=offset,
        )
        organization_id = self._require_org_id()
        offset_value = self._as_offset(offset)
        resp = fixture_persons_list.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            fixture_id=fixture_uuid,
            limit=limit,
            offset=offset_value,
        )

        self._ensure_ok(resp, "fixture_persons_list")

        parsed = self._unwrap_response(
            resp.parsed,
            FixturePersonsListFixturePersonsResponse,
            "fixture_persons_list",
        )
        data = parsed.data
        if isinstance(data, Unset):
            return []
        return list(data)

    def list_matches_by_season(
        self,
        season_id: str | UUID,
        *,
        limit: int = 500,
        offset: int | None = None,
    ) -> list[MatchModel]:
        """
        Return all matches for the given season.
        """
        self._require_value("season_id", str(season_id))
        season_uuid = self._as_uuid(season_id, "season_id")

        self._log_request(
            "fixture_list",
            season_id=str(season_uuid),
            limit=limit,
            offset=offset,
        )
        organization_id = self._require_org_id()
        offset_value = self._as_offset(offset)
        resp = fixture_list.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            season_id=season_uuid,
            external="entityId,personId",
            include="organizations,entities",
            limit=limit,
            offset=offset_value,
        )

        self._ensure_ok(resp, "fixture_list")

        parsed = self._unwrap_response(
            resp.parsed, FixtureListFixturesResponse, "fixture_list"
        )
        data = parsed.data
        if isinstance(data, Unset):
            return []
        return list(data)

    def get_team_by_id(self, entity_id: str | UUID) -> TeamModel:
        """
        Return the full entity (team) metadata for a given entity ID.
        """
        self._require_value("entity_id", str(entity_id))
        entity_uuid = self._as_uuid(entity_id, "entity_id")

        self._log_request("entity_detail", entity_id=str(entity_uuid))
        organization_id = self._require_org_id()
        resp = entity_detail.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            entity_id=entity_uuid,
            include="entities,organizations",
        )
        self._ensure_ok(resp, "entity_detail")
        parsed = self._unwrap_response(
            resp.parsed, EntityDetailEntitiesResponse, "entity_detail"
        )
        data = parsed.data
        if isinstance(data, Unset) or not data:
            raise NotFoundError(f"No team found for entity '{entity_uuid}'.")
        return data[0]

    def get_match_by_id(self, match_id: str | UUID) -> MatchModel:
        """
        Return the full match metadata for a given match ID.
        """
        self._require_value("match_id", str(match_id))
        fixture_uuid = self._as_uuid(match_id, "match_id")

        self._log_request("fixture_detail", fixture_id=str(fixture_uuid))
        organization_id = self._require_org_id()
        resp = fixture_detail.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            fixture_id=fixture_uuid,
            include="entities,organizations,persons",
            external="entityId,personId",
            hide_null=False,
            limit=1000,
        )

        self._ensure_ok(resp, "fixture_detail")
        parsed = self._unwrap_response(
            resp.parsed, FixtureDetailFixturesResponse, "fixture_detail"
        )
        data = parsed.data
        if isinstance(data, Unset) or not data:
            raise NotFoundError(f"No fixture found for id '{fixture_uuid}'.")
        return data[0]

    def get_match_events(
        self, match_id: str | UUID, setup_only: bool, with_scores: bool
    ) -> list[dict[str, Any]]:
        """
        Return the match events for a given match ID.
        """
        self._require_value("match_id", str(match_id))
        fixture_uuid = self._as_uuid(match_id, "match_id")

        self._log_request(
            "fixture_pbp_export",
            fixture_id=str(fixture_uuid),
            setup_only=setup_only,
            with_scores=with_scores,
        )
        organization_id = self._require_org_id()
        resp = fixture_pbp_export.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            fixture_id=fixture_uuid,
            limit=1000,
            only_setup=setup_only,
            with_scores=with_scores,
        )

        self._ensure_ok(resp, "fixture_pbp_export")
        self._unwrap_response(
            resp.parsed, FixturePbpExportSuccessResponse, "fixture_pbp_export"
        )
        data = self._json_data_from_response(resp, "fixture_pbp_export")
        if data is None:
            return []
        if not isinstance(data, list):
            raise UnexpectedResponseError("fixture_pbp_export: unexpected data shape")
        return data

    def get_players_by_ids(
        self,
        person_ids: str | Sequence[str | UUID],
        *,
        limit: int = 500,
        offset: int | None = None,
    ) -> list[PersonModel]:
        """
        Return the full player metadata for given player IDs (comma-separated).
        """
        if isinstance(person_ids, str):
            ids_list = [item.strip() for item in person_ids.split(",") if item.strip()]
        else:
            ids_list = [str(item) for item in person_ids if str(item).strip()]
        ids_text = ",".join(ids_list)
        self._require_value("person_ids", ids_text)

        self._log_request(
            "person_list",
            person_ids=ids_text,
            limit=limit,
            offset=offset,
        )
        organization_id = self._require_org_id()
        offset_value = self._as_offset(offset)
        person_id_arg: Any
        if len(ids_list) == 1:
            try:
                person_id_arg = self._as_uuid(ids_list[0], "person_ids")
            except ValidationError:
                person_id_arg = cast(Any, ids_text)
        else:
            person_id_arg = cast(Any, ids_text)
        resp = person_list.sync_detailed(
            client=self._ensure_client(),
            organization_id=organization_id,
            person_ids=person_id_arg,
            limit=limit,
            offset=offset_value,
        )

        self._ensure_ok(resp, "person_list")
        parsed = self._unwrap_response(
            resp.parsed, PersonListPersonsResponse, "person_list"
        )
        data = parsed.data
        if isinstance(data, Unset):
            return []
        return list(data)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.video_stream_local_model_format import VideoStreamLocalModelFormat
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.video_stream_local_model_fixture import VideoStreamLocalModelFixture
    from ..models.video_stream_local_model_organization import VideoStreamLocalModelOrganization


T = TypeVar("T", bound="VideoStreamLocalModel")


@_attrs_define
class VideoStreamLocalModel:
    """
    Attributes:
        url_id (Union[Unset, UUID]): The unique identifier of the video Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, VideoStreamLocalModelOrganization]): The organization that this Video Stream Local
            belongs to
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, VideoStreamLocalModelFixture]): The match
        provider (Union[Unset, str]): The code for the provider of the file Example: Test Provider.
        source_number (Union[Unset, int]): Unique identifier for the video source. This is unique for the
            provider/fixtureId/locale combination.  Unless the provider is supplying multiple sources per fixture/locale
            then this is normally 1. Default: 1. Example: 1.
        format_ (Union[Unset, VideoStreamLocalModelFormat]): The format of the video file
            >- `HLS` A HLS play list
            >- `MP4` One MP4 file
             Example: HLS.
        url (Union[Unset, str]): The URL where the file can be found Example: https://hls.host.com/video/index.m3u8.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    url_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "VideoStreamLocalModelOrganization"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "VideoStreamLocalModelFixture"] = UNSET
    provider: Union[Unset, str] = UNSET
    source_number: Union[Unset, int] = 1
    format_: Union[Unset, VideoStreamLocalModelFormat] = UNSET
    url: Union[Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        url_id: Union[Unset, str] = UNSET
        if not isinstance(self.url_id, Unset):
            url_id = str(self.url_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        provider = self.provider

        source_number = self.source_number

        format_: Union[Unset, str] = UNSET
        if not isinstance(self.format_, Unset):
            format_ = self.format_.value

        url = self.url

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if url_id is not UNSET:
            field_dict["urlId"] = url_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if provider is not UNSET:
            field_dict["provider"] = provider
        if source_number is not UNSET:
            field_dict["sourceNumber"] = source_number
        if format_ is not UNSET:
            field_dict["format"] = format_
        if url is not UNSET:
            field_dict["url"] = url
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.video_stream_local_model_fixture import VideoStreamLocalModelFixture
        from ..models.video_stream_local_model_organization import VideoStreamLocalModelOrganization

        d = dict(src_dict)
        _url_id = d.pop("urlId", UNSET)
        url_id: Union[Unset, UUID]
        if isinstance(_url_id, Unset):
            url_id = UNSET
        else:
            url_id = UUID(_url_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, VideoStreamLocalModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = VideoStreamLocalModelOrganization.from_dict(_organization)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, VideoStreamLocalModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = VideoStreamLocalModelFixture.from_dict(_fixture)

        provider = d.pop("provider", UNSET)

        source_number = d.pop("sourceNumber", UNSET)

        _format_ = d.pop("format", UNSET)
        format_: Union[Unset, VideoStreamLocalModelFormat]
        if isinstance(_format_, Unset):
            format_ = UNSET
        else:
            format_ = VideoStreamLocalModelFormat(_format_)

        url = d.pop("url", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        video_stream_local_model = cls(
            url_id=url_id,
            organization_id=organization_id,
            organization=organization,
            fixture_id=fixture_id,
            fixture=fixture,
            provider=provider,
            source_number=source_number,
            format_=format_,
            url=url,
            updated=updated,
            added=added,
        )

        return video_stream_local_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.uniform_items_model_item_type import UniformItemsModelItemType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.images_model import ImagesModel
    from ..models.uniform_items_model_colors import UniformItemsModelColors
    from ..models.uniform_items_model_organization import UniformItemsModelOrganization
    from ..models.uniform_items_model_uniform import UniformItemsModelUniform


T = TypeVar("T", bound="UniformItemsModel")


@_attrs_define
class UniformItemsModel:
    """
    Attributes:
        uniform_item_id (Union[Unset, UUID]): The unique identifier of the Uniform Item Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        uniform_id (Union[Unset, UUID]): The unique identifier of the uniform Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        uniform (Union[Unset, UniformItemsModelUniform]): The Uniform information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, UniformItemsModelOrganization]): The organization that this uniform_items belongs to
        item_type (Union[Unset, UniformItemsModelItemType]): The type of Uniform Item
            >- `BOTTOM` Bottom
            >- `GOALKEEPER_BOTTOM` Goal Keeper Bottom
            >- `GOALKEEPER_TOP` Goal Keeper Top
            >- `HELMET` Helmet
            >- `SOCKS` Socks
            >- `TOP` Top
            >- `WARMUP_BOTTOM` Warmup Bottom
            >- `WARMUP_TOP` Warmup Top
             Example: TOP.
        name_local (Union[Unset, str]): The name of the uniform_items in the [local](#section/Introduction/Character-
            Sets-and-Names) language Example: Test name local.
        name_latin (Union[None, Unset, str]): The name of the uniform_items in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: Test uniform.
        colors (Union[Unset, UniformItemsModelColors]):
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        images (Union[Unset, list['ImagesModel']]):
    """

    uniform_item_id: Union[Unset, UUID] = UNSET
    uniform_id: Union[Unset, UUID] = UNSET
    uniform: Union[Unset, "UniformItemsModelUniform"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "UniformItemsModelOrganization"] = UNSET
    item_type: Union[Unset, UniformItemsModelItemType] = UNSET
    name_local: Union[Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    colors: Union[Unset, "UniformItemsModelColors"] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        uniform_item_id: Union[Unset, str] = UNSET
        if not isinstance(self.uniform_item_id, Unset):
            uniform_item_id = str(self.uniform_item_id)

        uniform_id: Union[Unset, str] = UNSET
        if not isinstance(self.uniform_id, Unset):
            uniform_id = str(self.uniform_id)

        uniform: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.uniform, Unset):
            uniform = self.uniform.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        item_type: Union[Unset, str] = UNSET
        if not isinstance(self.item_type, Unset):
            item_type = self.item_type.value

        name_local = self.name_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        colors: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.colors, Unset):
            colors = self.colors.to_dict()

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if uniform_item_id is not UNSET:
            field_dict["uniformItemId"] = uniform_item_id
        if uniform_id is not UNSET:
            field_dict["uniformId"] = uniform_id
        if uniform is not UNSET:
            field_dict["uniform"] = uniform
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if item_type is not UNSET:
            field_dict["itemType"] = item_type
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if colors is not UNSET:
            field_dict["colors"] = colors
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.images_model import ImagesModel
        from ..models.uniform_items_model_colors import UniformItemsModelColors
        from ..models.uniform_items_model_organization import UniformItemsModelOrganization
        from ..models.uniform_items_model_uniform import UniformItemsModelUniform

        d = dict(src_dict)
        _uniform_item_id = d.pop("uniformItemId", UNSET)
        uniform_item_id: Union[Unset, UUID]
        if isinstance(_uniform_item_id, Unset):
            uniform_item_id = UNSET
        else:
            uniform_item_id = UUID(_uniform_item_id)

        _uniform_id = d.pop("uniformId", UNSET)
        uniform_id: Union[Unset, UUID]
        if isinstance(_uniform_id, Unset):
            uniform_id = UNSET
        else:
            uniform_id = UUID(_uniform_id)

        _uniform = d.pop("uniform", UNSET)
        uniform: Union[Unset, UniformItemsModelUniform]
        if isinstance(_uniform, Unset):
            uniform = UNSET
        else:
            uniform = UniformItemsModelUniform.from_dict(_uniform)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, UniformItemsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = UniformItemsModelOrganization.from_dict(_organization)

        _item_type = d.pop("itemType", UNSET)
        item_type: Union[Unset, UniformItemsModelItemType]
        if isinstance(_item_type, Unset):
            item_type = UNSET
        else:
            item_type = UniformItemsModelItemType(_item_type)

        name_local = d.pop("nameLocal", UNSET)

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        _colors = d.pop("colors", UNSET)
        colors: Union[Unset, UniformItemsModelColors]
        if isinstance(_colors, Unset):
            colors = UNSET
        else:
            colors = UniformItemsModelColors.from_dict(_colors)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        uniform_items_model = cls(
            uniform_item_id=uniform_item_id,
            uniform_id=uniform_id,
            uniform=uniform,
            organization_id=organization_id,
            organization=organization,
            item_type=item_type,
            name_local=name_local,
            name_latin=name_latin,
            colors=colors,
            updated=updated,
            added=added,
            images=images,
        )

        return uniform_items_model



from enum import Enum


class ImagesListOrganizationImageType(str, Enum):
    LOGO = "LOGO"
    LOGO_ALTERNATE = "LOGO_ALTERNATE"
    LOGO_BACKGROUND = "LOGO_BACKGROUND"
    PERSON_HEAD = "PERSON_HEAD"
    PERSON_POSE = "PERSON_POSE"
    PERSON_WAIST = "PERSON_WAIST"
    TEAM_PHOTO = "TEAM_PHOTO"
    UNIFORM = "UNIFORM"
    UNIFORM_ITEM = "UNIFORM_ITEM"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.standing_configurations_model_standing_building_build_type import (
    StandingConfigurationsModelStandingBuildingBuildType,
)
from ..models.standing_configurations_model_standing_building_fixture_types_item import (
    StandingConfigurationsModelStandingBuildingFixtureTypesItem,
)
from ..models.standing_configurations_model_standing_building_grouping import (
    StandingConfigurationsModelStandingBuildingGrouping,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="StandingConfigurationsModelStandingBuilding")


@_attrs_define
class StandingConfigurationsModelStandingBuilding:
    """Suilding definitions

    Attributes:
        build_type (StandingConfigurationsModelStandingBuildingBuildType): Overall standing Type (ROUND not used on live
            Standings) Example: OVERALL.
        grouping (StandingConfigurationsModelStandingBuildingGrouping): How to Group Example: NONE.
        fixture_types (list[StandingConfigurationsModelStandingBuildingFixtureTypesItem]):
        build_overall (Union[Unset, bool]): Build overall standings
        build_conferences (Union[Unset, bool]): Build standings by conference
        build_divisions (Union[Unset, bool]): Build standings by division
        blank_standing (Union[Unset, bool]): Give team blank row if no played
        include_live_fixtures (Union[Unset, bool]): Include live matches
        generate_live_standings (Union[Unset, bool]): Generate live matches
        validate_entities_structure (Union[Unset, bool]): Validate Entities against Fixture structure?
        decimal_places (Union[Unset, float]): Number of decimal places for percentage calculations Default: 4.0.
        skip_latest_flag (Union[Unset, bool]): Skip setting latest=True for ROUND standings?
        skip_clean_round_flag (Union[Unset, bool]): Skip cleaning future blank rounds?
        force_head_to_head (Union[Unset, bool]): Set to true in order to force head-to-head resolution even when there
            aren't enough mutual fixtures between entities in a h2h group
    """

    build_type: StandingConfigurationsModelStandingBuildingBuildType
    grouping: StandingConfigurationsModelStandingBuildingGrouping
    fixture_types: list[StandingConfigurationsModelStandingBuildingFixtureTypesItem]
    build_overall: Union[Unset, bool] = UNSET
    build_conferences: Union[Unset, bool] = UNSET
    build_divisions: Union[Unset, bool] = UNSET
    blank_standing: Union[Unset, bool] = UNSET
    include_live_fixtures: Union[Unset, bool] = UNSET
    generate_live_standings: Union[Unset, bool] = UNSET
    validate_entities_structure: Union[Unset, bool] = UNSET
    decimal_places: Union[Unset, float] = 4.0
    skip_latest_flag: Union[Unset, bool] = UNSET
    skip_clean_round_flag: Union[Unset, bool] = UNSET
    force_head_to_head: Union[Unset, bool] = UNSET

    def to_dict(self) -> dict[str, Any]:
        build_type = self.build_type.value

        grouping = self.grouping.value

        fixture_types = []
        for fixture_types_item_data in self.fixture_types:
            fixture_types_item = fixture_types_item_data.value
            fixture_types.append(fixture_types_item)

        build_overall = self.build_overall

        build_conferences = self.build_conferences

        build_divisions = self.build_divisions

        blank_standing = self.blank_standing

        include_live_fixtures = self.include_live_fixtures

        generate_live_standings = self.generate_live_standings

        validate_entities_structure = self.validate_entities_structure

        decimal_places = self.decimal_places

        skip_latest_flag = self.skip_latest_flag

        skip_clean_round_flag = self.skip_clean_round_flag

        force_head_to_head = self.force_head_to_head

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "buildType": build_type,
                "grouping": grouping,
                "fixtureTypes": fixture_types,
            }
        )
        if build_overall is not UNSET:
            field_dict["buildOverall"] = build_overall
        if build_conferences is not UNSET:
            field_dict["buildConferences"] = build_conferences
        if build_divisions is not UNSET:
            field_dict["buildDivisions"] = build_divisions
        if blank_standing is not UNSET:
            field_dict["blankStanding"] = blank_standing
        if include_live_fixtures is not UNSET:
            field_dict["includeLiveFixtures"] = include_live_fixtures
        if generate_live_standings is not UNSET:
            field_dict["generateLiveStandings"] = generate_live_standings
        if validate_entities_structure is not UNSET:
            field_dict["validateEntitiesStructure"] = validate_entities_structure
        if decimal_places is not UNSET:
            field_dict["decimalPlaces"] = decimal_places
        if skip_latest_flag is not UNSET:
            field_dict["skipLatestFlag"] = skip_latest_flag
        if skip_clean_round_flag is not UNSET:
            field_dict["skipCleanRoundFlag"] = skip_clean_round_flag
        if force_head_to_head is not UNSET:
            field_dict["forceHeadToHead"] = force_head_to_head

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        build_type = StandingConfigurationsModelStandingBuildingBuildType(d.pop("buildType"))

        grouping = StandingConfigurationsModelStandingBuildingGrouping(d.pop("grouping"))

        fixture_types = []
        _fixture_types = d.pop("fixtureTypes")
        for fixture_types_item_data in _fixture_types:
            fixture_types_item = StandingConfigurationsModelStandingBuildingFixtureTypesItem(fixture_types_item_data)

            fixture_types.append(fixture_types_item)

        build_overall = d.pop("buildOverall", UNSET)

        build_conferences = d.pop("buildConferences", UNSET)

        build_divisions = d.pop("buildDivisions", UNSET)

        blank_standing = d.pop("blankStanding", UNSET)

        include_live_fixtures = d.pop("includeLiveFixtures", UNSET)

        generate_live_standings = d.pop("generateLiveStandings", UNSET)

        validate_entities_structure = d.pop("validateEntitiesStructure", UNSET)

        decimal_places = d.pop("decimalPlaces", UNSET)

        skip_latest_flag = d.pop("skipLatestFlag", UNSET)

        skip_clean_round_flag = d.pop("skipCleanRoundFlag", UNSET)

        force_head_to_head = d.pop("forceHeadToHead", UNSET)

        standing_configurations_model_standing_building = cls(
            build_type=build_type,
            grouping=grouping,
            fixture_types=fixture_types,
            build_overall=build_overall,
            build_conferences=build_conferences,
            build_divisions=build_divisions,
            blank_standing=blank_standing,
            include_live_fixtures=include_live_fixtures,
            generate_live_standings=generate_live_standings,
            validate_entities_structure=validate_entities_structure,
            decimal_places=decimal_places,
            skip_latest_flag=skip_latest_flag,
            skip_clean_round_flag=skip_clean_round_flag,
            force_head_to_head=force_head_to_head,
        )

        return standing_configurations_model_standing_building
